Struct plaid::identity::Email[][src]

pub struct Email {
    pub data: String,
    pub primary: bool,
    pub type: String,
}

Fields

data: String

The email address.

primary: bool

When true, identifies the email address as the primary email on an account.

type: String

The type of email account as described by the financial institution. Possible values: primary, secondary, other