Struct plaid::identity::AccountWithOwners [−][src]
Fields
account_id: StringPlaid’s unique identifier for the account.
balances: AccountBalancesA set of fields describing the balance for an account.
mask: Option<String>The last 2-4 alphanumeric characters of an account's official account number. Note that the mask may be non-unique between an Item's accounts, and it may also not match the mask that the bank displays to the user.
name: StringThe name of the account, either assigned by the user or by the financial institution itself
official_name: Option<String>The official name of the account as given by the financial institution
type: StringPossible values: investment, credit, depository, loan, brokerage, other
subtype: Option<String>Possible values: 401a, 401k, 403B, 457b, 529, brokerage, cash isa, education savings account, gic, health reimbursement arrangement, hsa, isa, ira, lif, lira, lrif, lrsp, non-taxable brokerage account, other, prif, rdsp, resp, rlif, rrif, pension, profit sharing plan, retirement, roth, roth 401k, rrsp, sep ira, simple ira, sipp, stock plan, thrift savings plan, tfsa, trust, ugma, utma, variable annuity, credit card, paypal, cd, checking, savings, money market, prepaid, auto, commercial, construction, consumer, home, home equity, loan, mortgage, overdraft, line of credit, student, cash management, keogh, mutual fund, recurring, rewards, safe deposit, sarsep
verification_status: Option<String>The current verification status of an Auth Item initiated through Automated or Manual micro-deposits. Returned for Auth Items only.
owners: Vec<Identity>Data returned by the financial institution about the account owner or owners.